QoraStateUtils class

Utility for handling multiple states.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

combine2<T1, T2>(QoraState<T1> state1, QoraState<T2> state2) QoraState<(T1, T2)>
Combines exactly 2 states.
combine3<T1, T2, T3>(QoraState<T1> state1, QoraState<T2> state2, QoraState<T3> state3) QoraState<(T1, T2, T3)>
Combines exactly 3 states.
combineList<T>(List<QoraState<T>> states) QoraState<List<T>>
Combines multiple states into a single state.